import scipy as sc
import scipy.linalg as linalg
import math as m
from generate_data import *
import matplotlib
matplotlib.use('Agg')
from pylab import *
from matplotlib.pyplot import *
from matplotlib import rc
from matplotlib.pyplot import title as pytitle
from matplotlib.patches import Ellipse

def plot_data_yerr():
    """plot_data_yerr: Plot the data with the error bars in the y-direction

    History:
       2009-05-20 - Written - Bovy (NYU)

    """
    #Read the data
    data= read_data_yerr()
    ndata= len(data)
    #Put the data into x, y, and yerr
    x= sc.zeros(ndata)
    y= sc.zeros(ndata)
    yerr= sc.zeros(ndata)
    for ii in range(ndata):
        x[ii]= data[ii][0][0]
        y[ii]= data[ii][0][1]
        yerr[ii]= data[ii][1]
        
    plotfilename='data_yerr.png'
    fig_width=7.5
    fig_height=7.5
    fig_size =  [fig_width,fig_height]
    params = {'axes.labelsize': 12,
              'text.fontsize': 11,
              'legend.fontsize': 12,
              'xtick.labelsize':10,
              'ytick.labelsize':10,
              'text.usetex': True,
              'figure.figsize': fig_size}
    rcParams.update(params)
    errorbar(x,y,yerr,marker='o',color='k',linestyle='None')
    xlabel(r'$x$')
    ylabel(r'$y$')
    savefig(plotfilename,format='png')

    return 0

def plot_data_allerr():
    """plot_data_allerr: Plot the data with full error ellipses

    History:
       2009-05-20 - Written - Bovy (NYU)

    """
    #Read the data
    data= read_data_allerr()
    ndata= len(data)
    #Create the ellipses and the data points
    x= sc.zeros(ndata)
    y= sc.zeros(ndata)
    ellipses=[]
    ymin, ymax= 0, 0
    xmin, xmax= 0,0
    for ii in range(ndata):
        x[ii]= data[ii][0][0]
        y[ii]= data[ii][0][1]
        #Calculate the eigenvalues and the rotation angle
        ycovar= sc.zeros((2,2))
        ycovar[0,0]= data[ii][2]**2.
        ycovar[1,1]= data[ii][1]**2.
        ycovar[0,1]= data[ii][3]*m.sqrt(ycovar[0,0]*ycovar[1,1])
        ycovar[1,0]= ycovar[0,1]
        eigs= linalg.eig(ycovar)
        angle= m.atan(-eigs[1][0,1]/eigs[1][1,1])/m.pi*180.
        #print x[ii], y[ii], m.sqrt(ycovar[1,1]), m.sqrt(ycovar[0,0])
        #print m.sqrt(eigs[0][0]), m.sqrt(eigs[0][1]), angle
        thisellipse= Ellipse(sc.array([x[ii],y[ii]]),2*m.sqrt(eigs[0][0]),
                             2*m.sqrt(eigs[0][1]),angle)
        ellipses.append(thisellipse)
        if (x[ii]+m.sqrt(ycovar[0,0])) > xmax:
            xmax= (x[ii]+m.sqrt(ycovar[0,0]))
        if (x[ii]-m.sqrt(ycovar[0,0])) < xmin:
            xmin= (x[ii]-m.sqrt(ycovar[0,0]))
        if (y[ii]+m.sqrt(ycovar[1,1])) > ymax:
            ymax= (y[ii]+m.sqrt(ycovar[1,1]))
        if (y[ii]-m.sqrt(ycovar[1,1])) < ymin:
            ymin= (y[ii]-m.sqrt(ycovar[1,1]))
        
    plotfilename='data_allerr.png'
    fig_width=7.5
    fig_height=7.5
    fig_size =  [fig_width,fig_height]
    params = {'axes.labelsize': 12,
              'text.fontsize': 11,
              'legend.fontsize': 12,
              'xtick.labelsize':10,
              'ytick.labelsize':10,
              'text.usetex': True,
              'figure.figsize': fig_size}
    rcParams.update(params)
    fig= figure()
    ax= fig.add_subplot(111)
    #Add the error ellipses
    for e in ellipses:
        ax.add_artist(e)
        e.set_facecolor('none')
    ax.plot(x,y,color='k',marker='o',linestyle='None')
    ax.set_xlabel(r'$x$')
    ax.set_ylabel(r'$y$')
    ax.set_xlim((xmin,xmax))
    ax.set_ylim((ymin,ymax))
    savefig(plotfilename,format='png')

    return 0

